@@ -286,9 +286,9 @@ class PeopleScraper(InterfaceAuthenticated):
 
             role_number = int(row.get("data-pk"))
             status_with_review = cells[5].text_content().strip()
-            if status_with_review.startswith("Full Review Due "):
+            if status_with_review.startswith("Full Review Due ") or status_with_review.startswith("Full Ending "):
                 role_status = "Full"
-                review_date = parse(status_with_review.removeprefix("Full Review Due ").removeprefix("Full Ending  "))
+                review_date = parse(status_with_review.removeprefix("Full Review Due ").removeprefix("Full Ending "))
             else:
                 role_status = status_with_review
                 review_date = None
